unit VaxCallPickUpAgentList;

interface

uses
    System.SysUtils,
    System.Classes,
    Generics.Collections;

type TVaxAgentDetails = class

    public
        m_sAgentName: string;
end;

type TVaxCallPickAgentList = class

    m_objAgentList: TObjectDictionary<string, TVaxAgentDetails>;

 private

        function GenKey(sValue: string): string;
        procedure DeleteAgentAll();

        function FindAgent(sAgentName: string): TVaxAgentDetails;

 public

        constructor Create();
        Destructor Destroy();

        function AddAgent(sAgentName: string): boolean;
        procedure RemoveAgent(sAgentName: string);
        function GetCallPickUpGroupName(sAgentName: string): string;

        function IsAgentExisted(sAgentName: string): Boolean;
        function GetAllAgentName(var objAgentList: TStringList): boolean;
        function GetAgentCount(): Integer;

end;
implementation

        constructor TVaxCallPickAgentList.Create();
        begin
            m_objAgentList := TObjectDictionary<string, TVaxAgentDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxCallPickAgentList.Destroy();
        begin

            DeleteAgentAll();
            m_objAgentList.Free;

        end;

        function TVaxCallPickAgentList.GenKey(sValue: string): string;
        begin

            Result := AnsiLowerCase(sValue);

        end;

        procedure TVaxCallPickAgentList.DeleteAgentAll();
        begin

            m_objAgentList.Clear();

        end;

        function TVaxCallPickAgentList.FindAgent(sAgentName: string): TVaxAgentDetails;
        var
            objAgentDetails: TVaxAgentDetails;
            bResult: Boolean;
        begin
            objAgentDetails := Nil;

            bResult := m_objAgentList.TryGetValue(sAgentName, objAgentDetails);

            if(bResult = False) then
                Exit(nil);

            Result := objAgentDetails;
        end;

        function TVaxCallPickAgentList.AddAgent(sAgentName: string): boolean;
         var
            sKey: string;
            objAgentDetails: TVaxAgentDetails;

        begin
            objAgentDetails :=  FindAgent(sAgentName);

            if(objAgentDetails <> Nil) then
                Exit(False);

            objAgentDetails := TVaxAgentDetails.Create();

            objAgentDetails.m_sAgentName := sAgentName;
            m_objAgentList.Add(sAgentName, objAgentDetails);

            Exit(True);
        end;


        procedure TVaxCallPickAgentList.RemoveAgent(sAgentName: string);
         var
            sKey: string;
            objAgentDetails: TVaxAgentDetails;

        begin
            objAgentDetails :=  FindAgent(sAgentName);

            if(objAgentDetails <> Nil) then
                Exit();

             m_objAgentList.Remove(AnsiLowerCase(sAgentName));

        end;

        function TVaxCallPickAgentList.GetCallPickUpGroupName(sAgentName: string): string;
        var
            sKey: string;
            objAgentDetails: TVaxAgentDetails;

        begin
            objAgentDetails :=  FindAgent(sAgentName);

            if(objAgentDetails = Nil) then
                Exit('');

            Result :=  'PickUp1'

        end;

        function TVaxCallPickAgentList.IsAgentExisted(sAgentName: string): Boolean;
        var
            sKey: string;
            objAgentDetails: TVaxAgentDetails;

        begin
            objAgentDetails :=  FindAgent(sAgentName);

            if(objAgentDetails <> Nil) then
                Exit(True);

            Exit(False);

        end;

        function TVaxCallPickAgentList.GetAllAgentName(var objAgentList: TStringList): boolean;
        var
            objAgentDetails: TVaxAgentDetails;
            nIndex: Integer;
        begin

            if(m_objAgentList.Count <= 0) then
                Exit;

            for objAgentDetails in m_objAgentList.Values do
            begin
                objAgentList.Add(objAgentDetails.m_sAgentName);
            end;
        end;

        function TVaxCallPickAgentList.GetAgentCount(): Integer;
        begin
            Result := m_objAgentList.Count;
        end;





end.
