unit VaxCallPickUpList;

interface


uses
    System.SysUtils,
    System.Classes,
    Generics.Collections,
    VaxCallPickUpAgentList;

type TVaxCallPickDetails = class

   public
        m_objVaxCallPickUpAgentList: TVaxCallPickAgentList;
        m_sCallPickGroupName: string;

    public

        function AddAgent(sAgentName: string): boolean;
        procedure RemoveAgent(sAgentName: string);

        function GetAgentCount(): Integer;
        function GetAllAgentName(var objAgentList: TStringList): boolean;

        function IsAgentExisted(sAgentName: string): Boolean;

        constructor Create();

end;

type TVaxPickUpList = class

    m_objCallPickList: TObjectDictionary<string, TVaxCallPickDetails>;

 private

        function GenKey(sValue: string): string;
        procedure DeletePickUpAll();

        function FindPickUp(sQueue: string): TVaxCallPickDetails;

      public

        constructor Create();
        Destructor Destroy();

        procedure ResetOBJ();

        function AddPickUp(sPickUpGroupName: string): boolean;
        procedure RemovePickUp(sPickUpGroupName: string);

        function AddPickUpAgent(sPickUpGroupName: string; sAgentName: string): boolean;
        procedure RemovePickUpAgent(sPickUpGroupName: string; sAgentName: string);

        function GetPickUpGroupAgentList(sPickUpGroupName: string; var sListPickUpAgent: TStringList): boolean;

        function IsAgentExisted(sPickUpGroupName: string; sAgentName: string): boolean;

        function GetCallPickUpGroupName(sAgentName: string): string;

        function GetPickUpGroupList(sListPickUpName: TStringList): boolean;
        function GetPickUpAgentCount(sPickUpGroupName: string): Integer;
end;

implementation

      //////////////////////////////////////////////////////////////////////////////////////////
      //////////////////////////// Call PickUp Details //////////////////////////////////////////////

        function TVaxCallPickDetails.AddAgent(sAgentName: string): boolean;
        begin
              Result :=  m_objVaxCallPickUpAgentList.AddAgent(sAgentName);
        end;

        constructor TVaxCallPickDetails.Create();
        begin
              m_objVaxCallPickUpAgentList := TVaxCallPickAgentList.Create();
        end;

        procedure TVaxCallPickDetails.RemoveAgent(sAgentName: string);
        begin
              m_objVaxCallPickUpAgentList.RemoveAgent(sAgentName);
        end;

        function TVaxCallPickDetails.GetAgentCount(): Integer;
        begin
              Result := m_objVaxCallPickUpAgentList.GetAgentCount();
        end;

         function TVaxCallPickDetails.GetAllAgentName(var objAgentList: TStringList): boolean;
         begin
              Result := m_objVaxCallPickUpAgentList.GetAllAgentName(objAgentList);
         end;

        function TVaxCallPickDetails.IsAgentExisted(sAgentName: string): Boolean;
        begin
             Result := m_objVaxCallPickUpAgentList.IsAgentExisted(sAgentName);
        end;

      //////////////////////////////////////////////////////////////////////////////////////////
      /////////////////////////////// Queue List ///////////////////////////////////////////////

        constructor TVaxPickUpList.Create();
        begin
            m_objCallPickList := TObjectDictionary<string, TVaxCallPickDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxPickUpList.Destroy();
        begin
            DeletePickUpAll();
            m_objCallPickList.Free;

        end;

        function TVaxPickUpList.GenKey(sValue: string): string;
        begin
            Result := AnsiLowerCase(sValue);
        end;

        procedure TVaxPickUpList.DeletePickUpAll();
        begin
            m_objCallPickList.Clear;
        end;

        function TVaxPickUpList.FindPickUp(sQueue: string): TVaxCallPickDetails;
        var
            objVaxPickUpDetails: TVaxCallPickDetails;
            bResult: Boolean;
        begin
            objVaxPickUpDetails := Nil;

            bResult := m_objCallPickList.TryGetValue(sQueue, objVaxPickUpDetails);
            if(bResult = False) then
                Exit(nil);

            Result := objVaxPickUpDetails;
        end;

        procedure TVaxPickUpList.ResetOBJ();
        begin
            DeletePickUpAll();
        end;

       function TVaxPickUpList.AddPickUp(sPickUpGroupName: string): boolean;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

       begin

            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
                objVaxPickUpDetails := TVaxCallPickDetails.Create();

            objVaxPickUpDetails.m_sCallPickGroupName := sPickUpGroupName;
            m_objCallPickList.Add(sPickUpGroupName, objVaxPickUpDetails);

            Result := True;

        end;

        procedure TVaxPickUpList.RemovePickUp(sPickUpGroupName: string);
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

        begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit();

             m_objCallPickList.Remove(AnsiLowerCase(sPickUpGroupName));

        end;

        function TVaxPickUpList.AddPickUpAgent(sPickUpGroupName: string; sAgentName: string): Boolean;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

        begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit(False);

            Result := objVaxPickUpDetails.AddAgent(sAgentName);
        end;

        procedure TVaxPickUpList.RemovePickUpAgent(sPickUpGroupName: string; sAgentName: string) ;
         var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

         begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit();

            objVaxPickUpDetails.RemoveAgent(sPickUpGroupName);

        end;

        function TVaxPickUpList.GetPickUpGroupAgentList(sPickUpGroupName: string; var sListPickUpAgent: TStringList): boolean;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

         begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit(False);

             Result := objVaxPickUpDetails.GetAllAgentName(sListPickUpAgent);
        end;

        function TVaxPickUpList.IsAgentExisted(sPickUpGroupName: string; sAgentName: string): boolean;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

         begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit(False);


            Result := objVaxPickUpDetails.IsAgentExisted(sAgentName);

        end;

        function TVaxPickUpList.GetCallPickUpGroupName(sAgentName: string): string;
        var

        objCallPickUpDetails: TVaxCallPickDetails;

        begin
         if(m_objCallPickList.Count <= 0) then
                Exit;

            for objCallPickUpDetails in m_objCallPickList.Values do
            begin
                  if(objCallPickUpDetails.IsAgentExisted(sAgentName)) Then
                      Exit(objCallPickUpDetails.m_sCallPickGroupName);
            end;

            Result := '';
        end;

        function TVaxPickUpList.GetPickUpGroupList(sListPickUpName: TStringList): boolean;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

         begin

         if(m_objCallPickList.Count <= 0) then
                Exit(False);

            for objVaxPickUpDetails in m_objCallPickList.Values do
            begin
                  sListPickUpName.Add(objVaxPickUpDetails.m_sCallPickGroupName);
            end;

         Result := True;

        end;

        function TVaxPickUpList.GetPickUpAgentCount(sPickUpGroupName: string): Integer;
        var
            sKey: string;
            objVaxPickUpDetails: TVaxCallPickDetails;

         begin
            objVaxPickUpDetails :=  FindPickUp(sPickUpGroupName);

            if(objVaxPickUpDetails = Nil) then
               Exit(-1);

        Result := objVaxPickUpDetails.GetAgentCount();

        end;

end.
